/*
** pork_alias.c - interface to aliases.
** Copyright (C) 2002 Ryan McCabe <ryan@numb.org>
**
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License, version 2,
** as published by the Free Software Foundation.
*/

#include <config.h>

#include <unistd.h>
#include <string.h>
#include <stdlib.h>
#include <sys/types.h>

#include <pork_util.h>
#include <pork_list.h>
#include <pork_alias.h>

static int alias_compare(void *l, void *r) {
	const char *str = l;
	const struct alias *alias = r;

	return (strcasecmp(str, alias->alias));
}

static void alias_hash_remove(void *data) {
	struct alias *alias = data;

	free(alias->alias);
	free(alias->str);
	free(alias);
}

inline int alias_remove(hash_t *alias_hash, char *alias) {
	int ret;

	ret = hash_remove(alias_hash, alias,
			string_hash(alias, alias_hash->order));

	return (ret);
}

int alias_add(hash_t *alias_hash, char *alias, char *str) {
	u_int32_t hash = string_hash(alias, alias_hash->order);
	struct alias *new_alias = xmalloc(sizeof(*new_alias));

	alias_remove(alias_hash, alias);

	new_alias->alias = xstrdup(alias);
	new_alias->str = xstrdup(str);
	hash_add(alias_hash, new_alias, hash);
	return (0);
}

struct alias *alias_find(hash_t *alias_hash, char *alias) {
	dlist_t *node;
	u_int32_t hash = string_hash(alias, alias_hash->order);

	node = hash_find(alias_hash, alias, hash);
	if (node != NULL)
		return (node->data);

	return (NULL);
}

inline int alias_init(hash_t *alias_hash) {
	memset(alias_hash, 0, sizeof(*alias_hash));
	return (hash_init(alias_hash, 5, alias_compare, alias_hash_remove));
}
