/*
** pork_buddy_list.c - Buddy list screen widget.
** Copyright (C) 2002 Ryan McCabe <ryan@numb.org>
**
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License, version 2,
** as published by the Free Software Foundation.
*/

#ifndef __PORK_BUDDY_LIST_H
#define __PORK_BUDDY_LIST_H

#define BLIST_COLOR_BORDER_ACTIVE		(COLOR_PAIR(4) | A_BOLD)
#define BLIST_COLOR_BORDER_INACTIVE		(COLOR_PAIR(5))

#define BLIST_COLOR_CURSOR				(COLOR_PAIR(11) | A_BOLD)

#define BLIST_COLOR_STATUS_AWAY			(COLOR_PAIR(1) | A_BOLD)
#define BLIST_COLOR_STATUS_ACTIVE		(COLOR_PAIR(2) | A_BOLD)
#define BLIST_COLOR_STATUS_IDLE			(COLOR_PAIR(3) | A_BOLD)

#define BLIST_LAST_ROW(x)				((int) (x)->rows - 2)

#define BUDDY_DEFAULT_WIDTH				26
#define BUDDY_IDLE_WIDTH 				14

#define TYPE_BUDDY	0
#define TYPE_GROUP	1

struct buddy_list {
	WINDOW *win;
	u_int32_t cols;
	u_int32_t rows;
	dlist_t *lines;
	dlist_t *top;
	dlist_t *cursor;
	dlist_t *bot;
	u_int32_t show_idle:1;
	u_int32_t dirty:1;
};

struct blist_line {
	u_int32_t type;
	u_int32_t dirty:1;
	u_int32_t collapsed:1;
	int line;
	char *text;
	void *data;
};

void blist_scroll_down(struct buddy_list *blist);
void blist_scroll_up(struct buddy_list *blist);
void blist_cursor_down(struct buddy_list *blist);
void blist_cursor_up(struct buddy_list *blist);
void blist_redraw(struct buddy_list *blist);
void blist_refresh(struct buddy_list *blist, struct imwindow *imwindow);
int blist_init(struct aim_priv *priv);
int blist_toggle(struct buddy_list *blist, struct imwindow *imwindow);
int blist_show_idle(struct buddy_list *blist);
void blist_destroy(struct buddy_list *blist);
void blist_resize(struct buddy_list *blist, u_int32_t rows, u_int32_t cols);
void blist_destroy(struct buddy_list *blist);
struct blist_line *blist_get_cursor(struct buddy_list *blist);
void blist_collapse_group(struct buddy_list *blist, struct blist_line *group);
void blist_draw_buddy_label(struct buddy_list *blist, struct buddy *buddy);
void blist_draw_group_label(struct buddy_list *blist, struct group *group);
void blist_draw_border(struct buddy_list *blist);

void blist_add_group(struct buddy_list *blist, struct group *group);
void blist_del_group(struct buddy_list *blist, struct group *group);

void blist_add(struct buddy_list *blist, struct buddy *buddy);
void blist_del(struct buddy_list *blist, struct buddy *buddy);

#endif
